@@ -213,7 +213,7 @@ class HardwareIOSerializer(serializers.ModelSerializer):
 
 
 class DataTransformerConstantsSerializer(serializers.ModelSerializer):
-    datatransformer = serializers.PrimaryKeyRelatedField(many=True, read_only=True)
+    data_transformer = serializers.PrimaryKeyRelatedField(read_only=True)
 
     class Meta:
         model = DataTransformerConstants
